@@ -1,5 +1,5 @@
 import PySimpleGUI as Sg
-from .interface.登录 import 登录界面
+from .interface.login import *
 
 
 def 主题列表():
